@@ -12,6 +12,7 @@ module Jekyll
         def render(context)
           site = context.registers[:site]
           permalink = context.registers[:page]['permalink']
+          permalink_lang = context.registers[:page]['permalink_lang']
           site_url = @url.empty? ? site.config['url'] : @url
           i18n = "<meta http-equiv=\"Content-Language\" content=\"#{site.active_lang}\">\n"
           i18n += "<link rel=\"alternate\" hreflang=\"#{site.default_lang}\" "\
@@ -19,8 +20,9 @@ module Jekyll
           site.languages.each do |lang|
             next if lang == site.default_lang
 
+            url = permalink_lang && permalink_lang[lang] ? permalink_lang[lang] : permalink
             i18n += "<link rel=\"alternate\" hreflang=\"#{lang}\" "\
-            "href=\"#{site_url}/#{lang}#{permalink}\"/>\n"
+            "href=\"#{site_url}/#{lang}/#{url}\"/>\n"
           end
           i18n
         end
