@@ -43,7 +43,10 @@ module Jekyll
             while pids.length >= (lang == all_langs[-1] ? 1 : nproc)
               sleep 0.1
               pids.map do |lang, pid|
-                pids.delete lang if waitpid pid, Process::WNOHANG
+                next unless waitpid pid, Process::WNOHANG
+
+                pids.delete lang
+                raise "Polyglot subprocess #{pid} (#{lang}) failed (#{$?.exitstatus})" unless $?.success?
               end
             end
           end
@@ -60,6 +63,7 @@ module Jekyll
           process_language lang
         end
       end
+      Jekyll::Hooks.trigger :polyglot, :post_write
     end
 
     alias site_payload_orig site_payload
@@ -149,6 +153,7 @@ module Jekyll
         @file_langs[page_id] = lang
       end
       approved.values.each {|doc| assignPageRedirects(doc, docs) }
+      approved.values.each {|doc| assignPageLanguagePermalinks(doc, docs) }
       approved.values
     end
 
@@ -166,6 +171,20 @@ module Jekyll
       end
     end
 
+    def assignPageLanguagePermalinks(doc, docs)
+      pageId = doc.data['page_id']
+      if !pageId.nil? && !pageId.empty?
+        unless doc.data['permalink_lang'] then doc.data['permalink_lang'] = {} end
+        permalinkDocs = docs.select do |dd|
+          dd.data['page_id'] == pageId
+        end
+        permalinkDocs.each do |dd|
+          doclang = dd.data['lang'] || derive_lang_from_path(dd) || @default_lang
+          doc.data['permalink_lang'][doclang] = dd.data['permalink']
+        end
+      end
+    end
+
     # performs any necesarry operations on the documents before rendering them
     def process_documents(docs)
       # return if @active_lang == @default_lang
